==> boinc_7.16.16+dfsg.orig.tar.xz: boinc-client_release-7.16-7.16.16/README.md <==
# Status

| Build Status | Code Quality |
| --- | --- |
| ![Build Status](https://github.com/BOINC/boinc/workflows/Android/badge.svg) | [![codecov](https://codecov.io/gh/BOINC/boinc/branch/master/graph/badge.svg)](https://codecov.io/gh/BOINC/boinc) |
| ![Build Status](https://github.com/BOINC/boinc/workflows/Linux/badge.svg) | [![Coverity Scan Build Status](https://scan.coverity.com/projects/4226/badge.svg)](https://scan.coverity.com/projects/boinc-boinc) |
| ![Build Status](https://github.com/BOINC/boinc/workflows/Linux-MinGW/badge.svg) | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/BOINC/boinc/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/BOINC/boinc/?branch=master) |
| ![Build Status](https://github.com/BOINC/boinc/workflows/OSX/badge.svg) | |
| ![Build Status](https://github.com/BOINC/boinc/workflows/Windows/badge.svg) | |

# Social

[![Slack](https://img.shields.io/badge/slack-boincworkspace-blue?logo=slack)](https://join.slack.com/t/boincworkspace/shared_invite/enQtNzA3MTQ4NDA0Njc4LTM4NTEyZTY1MWEwZjAyNTVmOTg3NDA2NjVjZDQzMWQ3NmFjYTc4MTNkNTEyNjRkOTQ4MWU5Nzk3NzRhNTg0NDI) [![Discord](https://img.shields.io/badge/discord-boincnetwork-blue?logo=discord)](https://discord.gg/wPRafUq)

# BOINC

Project Website: https://boinc.berkeley.edu

## Want to create a project
See: https://boinc.berkeley.edu/trac/wiki

## Want to help
Read about all the [ways you can help](CONTRIBUTING.md)

### Note

The University of California holds the copyright on all BOINC source code. By
submitting contributions to the BOINC code, you irrevocably assign all right,
title, and interest, including copyright and all copyright rights, in such
contributions to The Regents of the University of California, who may then
use the code for any purpose that it desires.

## Reporting Security Issues
We strongly encourage you to report security problems to our private mailing
list and not by posting an issue.  You can do this by sending an email to
boinc_pmc@googlegroups.com.  This will be privately sent to the members of the
BOINC Project Management Committee.

# License
BOINC is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

BOINC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with BOINC.  If not, see <https://www.gnu.org/licenses/>.

==> boinc_7.18.1+dfsg.orig.tar.xz: boinc-client_release-7.18-7.18.1/README.md <==
# Status

| Build Status | Code Quality |
| --- | --- |
| [![Build Status](https://github.com/BOINC/boinc/workflows/Android/badge.svg)](https://github.com/BOINC/boinc/actions?query=workflow:Android+branch:master) | [![codecov](https://codecov.io/gh/BOINC/boinc/branch/master/graph/badge.svg)](https://codecov.io/gh/BOINC/boinc) |
| [![Build Status](https://github.com/BOINC/boinc/workflows/Linux/badge.svg)](https://github.com/BOINC/boinc/actions?query=workflow:Linux+branch:master) | [![Coverity Scan Build Status](https://scan.coverity.com/projects/4226/badge.svg)](https://scan.coverity.com/projects/boinc-boinc) |
| [![Build Status](https://github.com/BOINC/boinc/workflows/Linux-MinGW/badge.svg)](https://github.com/BOINC/boinc/actions?query=workflow:Linux-MinGW+branch:master) | [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/BOINC/boinc/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/BOINC/boinc/?branch=master) |
| [![Build Status](https://github.com/BOINC/boinc/workflows/OSX/badge.svg)](https://github.com/BOINC/boinc/actions?query=workflow:OSX+branch:master) | |
| [![Build Status](https://github.com/BOINC/boinc/workflows/Windows/badge.svg)](https://github.com/BOINC/boinc/actions?query=workflow:Windows+branch:master) | |

# Social

[![Slack](https://img.shields.io/badge/slack-boincworkspace-blue?logo=slack)](https://join.slack.com/t/boincworkspace/shared_invite/enQtNzA3MTQ4NDA0Njc4LTM4NTEyZTY1MWEwZjAyNTVmOTg3NDA2NjVjZDQzMWQ3NmFjYTc4MTNkNTEyNjRkOTQ4MWU5Nzk3NzRhNTg0NDI) [![Discord](https://img.shields.io/badge/discord-boincnetwork-blue?logo=discord)](https://discord.gg/wPRafUq)

# BOINC

Project Website: https://boinc.berkeley.edu

## Want to create a project
See: https://boinc.berkeley.edu/trac/wiki

## Want to help
Read about all the [ways you can help](CONTRIBUTING.md)

### Note

The University of California holds the copyright on all BOINC source code. By
submitting contributions to the BOINC code, you irrevocably assign all right,
title, and interest, including copyright and all copyright rights, in such
contributions to The Regents of the University of California, who may then
use the code for any purpose that it desires.

## Reporting Security Issues
We strongly encourage you to report security problems to our private mailing
list and not by posting an issue.  You can do this by sending an email to
boinc_pmc@googlegroups.com.  This will be privately sent to the members of the
BOINC Project Management Committee.

# License
BOINC is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

BOINC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with BOINC.  If not, see <https://www.gnu.org/licenses/>.
